Module state

Module state 

Connection state published by the driver to consumers via tokio::sync::watch. See ARCHITECTURE.md “ConnectionState”.

Enums

ConnectionState
Observable connection state of a Request or Subscribe handle.