pub struct Subscription { /* private fields */ }Implementations
Sourceimpl Subscription
impl Subscription
pub fn new(group_msg: GroupStatusMsg) -> Self
pub fn id(&self) -> u32
pub fn update(&mut self, buffer: Vec<u8>)
pub fn read<V>(&self) -> Option<(TimeSpec, V)>where
V: GetParameterTuple,
Sourcepub fn read_all<V>(&self) -> Option<(TimeSpec, Vec<V>)>where
V: GetParameterValue + Default,
pub fn read_all<V>(&self) -> Option<(TimeSpec, Vec<V>)>where
V: GetParameterValue + Default,
Reads all subscribed parameters and returns their values as a flat Vec<V>.
Each parameter’s elements are decoded individually using decode_parameter_value,
regardless of the number of parameters or their array sizes.
The caller chooses the output type:
ⓘ
sub.read_all::<f64>() // all values as f64
sub.read_all::<String>() // all values as their string representation
sub.read_all::<i64>() // all values as i64pub fn notify<F>(&mut self, cb: F)
pub fn name(&self) -> String