Connection state published by the driver to consumers via
tokio::sync::watch. See ARCHITECTURE.md “ConnectionState”.
Enums
- Connection
State - Observable connection state of a
RequestorSubscribehandle.
Connection state published by the driver to consumers via
tokio::sync::watch. See ARCHITECTURE.md “ConnectionState”.
Request or Subscribe handle.